# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stanza/hub/v1/config.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from stanza.hub.v1 import common_pb2 as stanza_dot_hub_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1astanza/hub/v1/config.proto\x12\rstanza.hub.v1\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a\x1astanza/hub/v1/common.proto\"\x91\x01\n\x15GetGuardConfigRequest\x12&\n\x0cversion_seen\x18\x01 \x01(\tH\x00R\x0bversionSeen\x88\x01\x01\x12?\n\x08selector\x18\x02 \x01(\x0b\x32#.stanza.hub.v1.GuardServiceSelectorR\x08selectorB\x0f\n\r_version_seen\"\x90\x01\n\x16GetGuardConfigResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12(\n\x10\x63onfig_data_sent\x18\x02 \x01(\x08R\x0e\x63onfigDataSent\x12\x32\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x1a.stanza.hub.v1.GuardConfigR\x06\x63onfig\"\xa6\x01\n\x0bGuardConfig\x12\x36\n\x17validate_ingress_tokens\x18\x01 \x01(\x08R\x15validateIngressTokens\x12\x1f\n\x0b\x63heck_quota\x18\x05 \x01(\x08R\ncheckQuota\x12\x1d\n\nquota_tags\x18\x06 \x03(\tR\tquotaTags\x12\x1f\n\x0breport_only\x18\x07 \x01(\x08R\nreportOnly\"T\n\x18GetBrowserContextRequest\x12\x38\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32\x1e.stanza.hub.v1.FeatureSelectorR\x07\x66\x65\x61ture\"b\n\x19GetBrowserContextResponse\x12\x45\n\x0f\x66\x65\x61ture_configs\x18\x02 \x03(\x0b\x32\x1c.stanza.hub.v1.FeatureConfigR\x0e\x66\x65\x61tureConfigs\"Y\n\rFeatureConfig\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x34\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1c.stanza.hub.v1.BrowserConfigR\x06\x63onfig\"\xf5\x02\n\rBrowserConfig\x12,\n\x0f\x65nabled_percent\x18\x02 \x01(\rH\x00R\x0e\x65nabledPercent\x88\x01\x01\x12\x33\n\x13\x61\x63tion_code_enabled\x18\x03 \x01(\rH\x01R\x11\x61\x63tionCodeEnabled\x88\x01\x01\x12,\n\x0fmessage_enabled\x18\x04 \x01(\tH\x02R\x0emessageEnabled\x88\x01\x01\x12\x35\n\x14\x61\x63tion_code_disabled\x18\x05 \x01(\rH\x03R\x12\x61\x63tionCodeDisabled\x88\x01\x01\x12.\n\x10message_disabled\x18\x06 \x01(\tH\x04R\x0fmessageDisabled\x88\x01\x01\x42\x12\n\x10_enabled_percentB\x16\n\x14_action_code_enabledB\x12\n\x10_message_enabledB\x17\n\x15_action_code_disabledB\x13\n\x11_message_disabled\"\xa6\x01\n\x17GetServiceConfigRequest\x12!\n\x0cversion_seen\x18\x01 \x01(\tR\x0bversionSeen\x12\x38\n\x07service\x18\x02 \x01(\x0b\x32\x1e.stanza.hub.v1.ServiceSelectorR\x07service\x12 \n\tclient_id\x18\x03 \x01(\tH\x00R\x08\x63lientId\x88\x01\x01\x42\x0c\n\n_client_id\"\x94\x01\n\x18GetServiceConfigResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12(\n\x10\x63onfig_data_sent\x18\x02 \x01(\x08R\x0e\x63onfigDataSent\x12\x34\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x1c.stanza.hub.v1.ServiceConfigR\x06\x63onfig\"\xd4\x02\n\rServiceConfig\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tH\x00R\ncustomerId\x88\x01\x01\x12\x42\n\x0ctrace_config\x18\x03 \x01(\x0b\x32\x1a.stanza.hub.v1.TraceConfigH\x01R\x0btraceConfig\x88\x01\x01\x12\x45\n\rmetric_config\x18\x04 \x01(\x0b\x32\x1b.stanza.hub.v1.MetricConfigH\x02R\x0cmetricConfig\x88\x01\x01\x12K\n\x0fsentinel_config\x18\x05 \x01(\x0b\x32\x1d.stanza.hub.v1.SentinelConfigH\x03R\x0esentinelConfig\x88\x01\x01\x42\x0e\n\x0c_customer_idB\x0f\n\r_trace_configB\x10\n\x0e_metric_configB\x12\n\x10_sentinel_config\"\x81\x03\n\x0bTraceConfig\x12(\n\rcollector_url\x18\x01 \x01(\tH\x00R\x0c\x63ollectorUrl\x88\x01\x01\x12\x33\n\x13sample_rate_default\x18\x03 \x01(\x02H\x01R\x11sampleRateDefault\x88\x01\x01\x12@\n\toverrides\x18\x04 \x03(\x0b\x32\".stanza.hub.v1.TraceConfigOverrideR\toverrides\x12T\n\x15header_sample_configs\x18\x05 \x03(\x0b\x32 .stanza.hub.v1.HeaderTraceConfigR\x13headerSampleConfigs\x12Q\n\x14param_sample_configs\x18\x06 \x03(\x0b\x32\x1f.stanza.hub.v1.ParamTraceConfigR\x12paramSampleConfigsB\x10\n\x0e_collector_urlB\x16\n\x14_sample_rate_default\"J\n\x0cMetricConfig\x12(\n\rcollector_url\x18\x01 \x01(\tH\x00R\x0c\x63ollectorUrl\x88\x01\x01\x42\x10\n\x0e_collector_url\"\xc7\x02\n\x0eSentinelConfig\x12?\n\x19\x63ircuitbreaker_rules_json\x18\x01 \x01(\tH\x00R\x17\x63ircuitbreakerRulesJson\x88\x01\x01\x12+\n\x0f\x66low_rules_json\x18\x02 \x01(\tH\x01R\rflowRulesJson\x88\x01\x01\x12\x35\n\x14isolation_rules_json\x18\x03 \x01(\tH\x02R\x12isolationRulesJson\x88\x01\x01\x12/\n\x11system_rules_json\x18\x04 \x01(\tH\x03R\x0fsystemRulesJson\x88\x01\x01\x42\x1c\n\x1a_circuitbreaker_rules_jsonB\x12\n\x10_flow_rules_jsonB\x17\n\x15_isolation_rules_jsonB\x14\n\x12_system_rules_json\"z\n\x13TraceConfigOverride\x12\x1f\n\x0bsample_rate\x18\x01 \x01(\x02R\nsampleRate\x12\x42\n\x0espan_selectors\x18\x02 \x03(\x0b\x32\x1b.stanza.hub.v1.SpanSelectorR\rspanSelectors\"K\n\x0cSpanSelector\x12%\n\x0eotel_attribute\x18\x01 \x01(\tR\rotelAttribute\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"\xbd\x01\n\x11HeaderTraceConfig\x12\x42\n\x0espan_selectors\x18\x01 \x03(\x0b\x32\x1b.stanza.hub.v1.SpanSelectorR\rspanSelectors\x12\x30\n\x14request_header_names\x18\x02 \x03(\tR\x12requestHeaderNames\x12\x32\n\x15response_header_names\x18\x03 \x03(\tR\x13responseHeaderNames\"\x7f\n\x10ParamTraceConfig\x12\x42\n\x0espan_selectors\x18\x01 \x03(\x0b\x32\x1b.stanza.hub.v1.SpanSelectorR\rspanSelectors\x12\'\n\x0fparameter_names\x18\x02 \x03(\tR\x0eparameterNames2\xef\x07\n\rConfigService\x12\xfc\x01\n\x0eGetGuardConfig\x12$.stanza.hub.v1.GetGuardConfigRequest\x1a%.stanza.hub.v1.GetGuardConfigResponse\"\x9c\x01\x92\x41~\x12\x10Get Guard Config\x1a\x32Used by SDK to get a Guard Config from Stanza Hub.J6\n\x03\x32\x30\x30\x12/\n\x02OK\x12)\n\'\x1a%.stanza.hub.v1.GetGuardConfigResponse\x82\xd3\xe4\x93\x02\x15\"\x10/v1/config/guard:\x01*\x12\xd0\x03\n\x11GetBrowserContext\x12\'.stanza.hub.v1.GetBrowserContextRequest\x1a(.stanza.hub.v1.GetBrowserContextResponse\"\xe7\x02\x92\x41\xc5\x02\x12\x13Get Browser Context\x1a\x35Used by SDK to get a Browser Context from Stanza Hub.J\x8a\x01\n\x03\x32\x30\x30\x12\x82\x01\n\x02OK\x12,\n*\x1a(.stanza.hub.v1.GetBrowserContextResponse\x1aN\n\x04\x45Tag\x12\x46\n<Unique entity identifier for this specific resource version.\x12\x06stringJj\n\x03\x33\x30\x34\x12\x63\n\x11OK, Not Modified.\x1aN\n\x04\x45Tag\x12\x46\n<Unique entity identifier for this specific resource version.\x12\x06string\x82\xd3\xe4\x93\x02\x18\"\x13/v1/context/browser:\x01*\x12\x8b\x02\n\x10GetServiceConfig\x12&.stanza.hub.v1.GetServiceConfigRequest\x1a\'.stanza.hub.v1.GetServiceConfigResponse\"\xa5\x01\x92\x41\x84\x01\x12\x12Get Service Config\x1a\x34Used by SDK to get a Service Config from Stanza Hub.J8\n\x03\x32\x30\x30\x12\x31\n\x02OK\x12+\n)\x1a\'.stanza.hub.v1.GetServiceConfigResponse\x82\xd3\xe4\x93\x02\x17\"\x12/v1/config/service:\x01*B\x8b\x01\n\x11\x63om.stanza.hub.v1B\x0b\x43onfigProtoP\x01Z\x13stanza/hub/v1;hubpb\xa2\x02\x03SHX\xaa\x02\rStanza.Hub.V1\xca\x02\rStanza\\Hub\\V1\xe2\x02\x19Stanza\\Hub\\V1\\GPBMetadata\xea\x02\x0fStanza::Hub::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'stanza.hub.v1.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.stanza.hub.v1B\013ConfigProtoP\001Z\023stanza/hub/v1;hubpb\242\002\003SHX\252\002\rStanza.Hub.V1\312\002\rStanza\\Hub\\V1\342\002\031Stanza\\Hub\\V1\\GPBMetadata\352\002\017Stanza::Hub::V1'
  _globals['_CONFIGSERVICE'].methods_by_name['GetGuardConfig']._options = None
  _globals['_CONFIGSERVICE'].methods_by_name['GetGuardConfig']._serialized_options = b'\222A~\022\020Get Guard Config\0322Used by SDK to get a Guard Config from Stanza Hub.J6\n\003200\022/\n\002OK\022)\n\'\032%.stanza.hub.v1.GetGuardConfigResponse\202\323\344\223\002\025\"\020/v1/config/guard:\001*'
  _globals['_CONFIGSERVICE'].methods_by_name['GetBrowserContext']._options = None
  _globals['_CONFIGSERVICE'].methods_by_name['GetBrowserContext']._serialized_options = b'\222A\305\002\022\023Get Browser Context\0325Used by SDK to get a Browser Context from Stanza Hub.J\212\001\n\003200\022\202\001\n\002OK\022,\n*\032(.stanza.hub.v1.GetBrowserContextResponse\032N\n\004ETag\022F\n<Unique entity identifier for this specific resource version.\022\006stringJj\n\003304\022c\n\021OK, Not Modified.\032N\n\004ETag\022F\n<Unique entity identifier for this specific resource version.\022\006string\202\323\344\223\002\030\"\023/v1/context/browser:\001*'
  _globals['_CONFIGSERVICE'].methods_by_name['GetServiceConfig']._options = None
  _globals['_CONFIGSERVICE'].methods_by_name['GetServiceConfig']._serialized_options = b'\222A\204\001\022\022Get Service Config\0324Used by SDK to get a Service Config from Stanza Hub.J8\n\003200\0221\n\002OK\022+\n)\032\'.stanza.hub.v1.GetServiceConfigResponse\202\323\344\223\002\027\"\022/v1/config/service:\001*'
  _globals['_GETGUARDCONFIGREQUEST']._serialized_start=152
  _globals['_GETGUARDCONFIGREQUEST']._serialized_end=297
  _globals['_GETGUARDCONFIGRESPONSE']._serialized_start=300
  _globals['_GETGUARDCONFIGRESPONSE']._serialized_end=444
  _globals['_GUARDCONFIG']._serialized_start=447
  _globals['_GUARDCONFIG']._serialized_end=613
  _globals['_GETBROWSERCONTEXTREQUEST']._serialized_start=615
  _globals['_GETBROWSERCONTEXTREQUEST']._serialized_end=699
  _globals['_GETBROWSERCONTEXTRESPONSE']._serialized_start=701
  _globals['_GETBROWSERCONTEXTRESPONSE']._serialized_end=799
  _globals['_FEATURECONFIG']._serialized_start=801
  _globals['_FEATURECONFIG']._serialized_end=890
  _globals['_BROWSERCONFIG']._serialized_start=893
  _globals['_BROWSERCONFIG']._serialized_end=1266
  _globals['_GETSERVICECONFIGREQUEST']._serialized_start=1269
  _globals['_GETSERVICECONFIGREQUEST']._serialized_end=1435
  _globals['_GETSERVICECONFIGRESPONSE']._serialized_start=1438
  _globals['_GETSERVICECONFIGRESPONSE']._serialized_end=1586
  _globals['_SERVICECONFIG']._serialized_start=1589
  _globals['_SERVICECONFIG']._serialized_end=1929
  _globals['_TRACECONFIG']._serialized_start=1932
  _globals['_TRACECONFIG']._serialized_end=2317
  _globals['_METRICCONFIG']._serialized_start=2319
  _globals['_METRICCONFIG']._serialized_end=2393
  _globals['_SENTINELCONFIG']._serialized_start=2396
  _globals['_SENTINELCONFIG']._serialized_end=2723
  _globals['_TRACECONFIGOVERRIDE']._serialized_start=2725
  _globals['_TRACECONFIGOVERRIDE']._serialized_end=2847
  _globals['_SPANSELECTOR']._serialized_start=2849
  _globals['_SPANSELECTOR']._serialized_end=2924
  _globals['_HEADERTRACECONFIG']._serialized_start=2927
  _globals['_HEADERTRACECONFIG']._serialized_end=3116
  _globals['_PARAMTRACECONFIG']._serialized_start=3118
  _globals['_PARAMTRACECONFIG']._serialized_end=3245
  _globals['_CONFIGSERVICE']._serialized_start=3248
  _globals['_CONFIGSERVICE']._serialized_end=4255
# @@protoc_insertion_point(module_scope)
