# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stanza/hub/v1/stream.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from stanza.hub.v1 import common_pb2 as stanza_dot_hub_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1astanza/hub/v1/stream.proto\x12\rstanza.hub.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1astanza/hub/v1/common.proto\"\xb3\x01\n\x14UpdateStreamsRequest\x12#\n\nguard_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\tguardName\x12&\n\x0b\x65nvironment\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x0b\x65nvironment\x12\x38\n\x08requests\x18\x03 \x03(\x0b\x32\x1c.stanza.hub.v1.StreamRequestR\x08requests\x12\x14\n\x05\x65nded\x18\x04 \x03(\tR\x05\x65nded\"N\n\x15UpdateStreamsResponse\x12\x35\n\x07results\x18\x01 \x03(\x0b\x32\x1b.stanza.hub.v1.StreamResultR\x07results\"\xfd\x01\n\rStreamRequest\x12\x18\n\x07\x66\x65\x61ture\x18\x01 \x01(\tR\x07\x66\x65\x61ture\x12&\n\x04tags\x18\x02 \x03(\x0b\x32\x12.stanza.hub.v1.TagR\x04tags\x12*\n\x0epriority_boost\x18\x03 \x01(\x05H\x00R\rpriorityBoost\x88\x01\x01\x12!\n\tstream_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02R\x08streamId\x12#\n\nmax_weight\x18\x05 \x01(\x02\x42\x04\xe2\x41\x01\x02R\tmaxWeight\x12#\n\nmin_weight\x18\x06 \x01(\x02\x42\x04\xe2\x41\x01\x02R\tminWeightB\x11\n\x0f_priority_boost\"\\\n\x0cStreamResult\x12!\n\tstream_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08streamId\x12)\n\x10\x61llocated_weight\x18\x02 \x01(\x02R\x0f\x61llocatedWeight2\x91\x01\n\x15StreamBalancerService\x12x\n\rUpdateStreams\x12#.stanza.hub.v1.UpdateStreamsRequest\x1a$.stanza.hub.v1.UpdateStreamsResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/updatestreams:\x01*B\x8b\x01\n\x11\x63om.stanza.hub.v1B\x0bStreamProtoP\x01Z\x13stanza/hub/v1;hubpb\xa2\x02\x03SHX\xaa\x02\rStanza.Hub.V1\xca\x02\rStanza\\Hub\\V1\xe2\x02\x19Stanza\\Hub\\V1\\GPBMetadata\xea\x02\x0fStanza::Hub::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'stanza.hub.v1.stream_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.stanza.hub.v1B\013StreamProtoP\001Z\023stanza/hub/v1;hubpb\242\002\003SHX\252\002\rStanza.Hub.V1\312\002\rStanza\\Hub\\V1\342\002\031Stanza\\Hub\\V1\\GPBMetadata\352\002\017Stanza::Hub::V1'
  _globals['_UPDATESTREAMSREQUEST'].fields_by_name['guard_name']._options = None
  _globals['_UPDATESTREAMSREQUEST'].fields_by_name['guard_name']._serialized_options = b'\342A\001\002'
  _globals['_UPDATESTREAMSREQUEST'].fields_by_name['environment']._options = None
  _globals['_UPDATESTREAMSREQUEST'].fields_by_name['environment']._serialized_options = b'\342A\001\002'
  _globals['_STREAMREQUEST'].fields_by_name['stream_id']._options = None
  _globals['_STREAMREQUEST'].fields_by_name['stream_id']._serialized_options = b'\342A\001\002'
  _globals['_STREAMREQUEST'].fields_by_name['max_weight']._options = None
  _globals['_STREAMREQUEST'].fields_by_name['max_weight']._serialized_options = b'\342A\001\002'
  _globals['_STREAMREQUEST'].fields_by_name['min_weight']._options = None
  _globals['_STREAMREQUEST'].fields_by_name['min_weight']._serialized_options = b'\342A\001\002'
  _globals['_STREAMRESULT'].fields_by_name['stream_id']._options = None
  _globals['_STREAMRESULT'].fields_by_name['stream_id']._serialized_options = b'\342A\001\002'
  _globals['_STREAMBALANCERSERVICE'].methods_by_name['UpdateStreams']._options = None
  _globals['_STREAMBALANCERSERVICE'].methods_by_name['UpdateStreams']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/updatestreams:\001*'
  _globals['_UPDATESTREAMSREQUEST']._serialized_start=137
  _globals['_UPDATESTREAMSREQUEST']._serialized_end=316
  _globals['_UPDATESTREAMSRESPONSE']._serialized_start=318
  _globals['_UPDATESTREAMSRESPONSE']._serialized_end=396
  _globals['_STREAMREQUEST']._serialized_start=399
  _globals['_STREAMREQUEST']._serialized_end=652
  _globals['_STREAMRESULT']._serialized_start=654
  _globals['_STREAMRESULT']._serialized_end=746
  _globals['_STREAMBALANCERSERVICE']._serialized_start=749
  _globals['_STREAMBALANCERSERVICE']._serialized_end=894
# @@protoc_insertion_point(module_scope)
