# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stanza/hub/v1/usage.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from stanza.hub.v1 import common_pb2 as stanza_dot_hub_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19stanza/hub/v1/usage.proto\x12\rstanza.hub.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1astanza/hub/v1/common.proto\"\xb9\x07\n\x0fGetUsageRequest\x12&\n\x0b\x65nvironment\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0b\x65nvironment\x12\x19\n\x05guard\x18\x02 \x01(\tH\x00R\x05guard\x88\x01\x01\x12G\n\x10guard_query_mode\x18\x03 \x01(\x0e\x32\x18.stanza.hub.v1.QueryModeH\x01R\x0eguardQueryMode\x88\x01\x01\x12;\n\x08start_ts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x02R\x07startTs\x12\x37\n\x06\x65nd_ts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x02R\x05\x65ndTs\x12\x1b\n\x06\x61pikey\x18\x06 \x01(\tH\x02R\x06\x61pikey\x88\x01\x01\x12\x1d\n\x07\x66\x65\x61ture\x18\x07 \x01(\tH\x03R\x07\x66\x65\x61ture\x88\x01\x01\x12K\n\x12\x66\x65\x61ture_query_mode\x18\x08 \x01(\x0e\x32\x18.stanza.hub.v1.QueryModeH\x04R\x10\x66\x65\x61tureQueryMode\x88\x01\x01\x12\x1d\n\x07service\x18\x0f \x01(\tH\x05R\x07service\x88\x01\x01\x12K\n\x12service_query_mode\x18\x10 \x01(\x0e\x32\x18.stanza.hub.v1.QueryModeH\x06R\x10serviceQueryMode\x88\x01\x01\x12\x1f\n\x08priority\x18\t \x01(\x05H\x07R\x08priority\x88\x01\x01\x12M\n\x13priority_query_mode\x18\n \x01(\x0e\x32\x18.stanza.hub.v1.QueryModeH\x08R\x11priorityQueryMode\x88\x01\x01\x12\x1f\n\x0breport_tags\x18\x0b \x03(\tR\nreportTags\x12&\n\x04tags\x18\x0c \x03(\x0b\x32\x12.stanza.hub.v1.TagR\x04tags\x12+\n\x0freport_all_tags\x18\r \x01(\x08H\tR\rreportAllTags\x88\x01\x01\x12\x17\n\x04step\x18\x0e \x01(\tH\nR\x04step\x88\x01\x01\x42\x08\n\x06_guardB\x13\n\x11_guard_query_modeB\t\n\x07_apikeyB\n\n\x08_featureB\x15\n\x13_feature_query_modeB\n\n\x08_serviceB\x15\n\x13_service_query_modeB\x0b\n\t_priorityB\x16\n\x14_priority_query_modeB\x12\n\x10_report_all_tagsB\x07\n\x05_step\"J\n\x10GetUsageResponse\x12\x36\n\x06result\x18\x01 \x03(\x0b\x32\x1e.stanza.hub.v1.UsageTimeseriesR\x06result\"\x97\x02\n\x0fUsageTimeseries\x12\x33\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1f.stanza.hub.v1.UsageTSDataPointR\x04\x64\x61ta\x12\x1d\n\x07\x66\x65\x61ture\x18\x03 \x01(\tH\x00R\x07\x66\x65\x61ture\x88\x01\x01\x12\x1f\n\x08priority\x18\x04 \x01(\x05H\x01R\x08priority\x88\x01\x01\x12&\n\x04tags\x18\x05 \x03(\x0b\x32\x12.stanza.hub.v1.TagR\x04tags\x12\x19\n\x05guard\x18\x06 \x01(\tH\x02R\x05guard\x88\x01\x01\x12\x1d\n\x07service\x18\x07 \x01(\tH\x03R\x07service\x88\x01\x01\x42\n\n\x08_featureB\x0b\n\t_priorityB\x08\n\x06_guardB\n\n\x08_service\"\x86\x04\n\x10UsageTSDataPoint\x12\x35\n\x08start_ts\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07startTs\x12\x31\n\x06\x65nd_ts\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x05\x65ndTs\x12\x18\n\x07granted\x18\x03 \x01(\x05R\x07granted\x12%\n\x0egranted_weight\x18\x04 \x01(\x02R\rgrantedWeight\x12\x1f\n\x0bnot_granted\x18\x05 \x01(\x05R\nnotGranted\x12,\n\x12not_granted_weight\x18\x06 \x01(\x02R\x10notGrantedWeight\x12\x1e\n\x08\x62\x65_burst\x18\x07 \x01(\x05H\x00R\x07\x62\x65\x42urst\x88\x01\x01\x12+\n\x0f\x62\x65_burst_weight\x18\x08 \x01(\x02H\x01R\rbeBurstWeight\x88\x01\x01\x12(\n\rparent_reject\x18\t \x01(\x05H\x02R\x0cparentReject\x88\x01\x01\x12\x35\n\x14parent_reject_weight\x18\n \x01(\x02H\x03R\x12parentRejectWeight\x88\x01\x01\x42\x0b\n\t_be_burstB\x12\n\x10_be_burst_weightB\x10\n\x0e_parent_rejectB\x17\n\x15_parent_reject_weight*R\n\tQueryMode\x12\x1a\n\x16QUERY_MODE_UNSPECIFIED\x10\x00\x12\x12\n\x0eQUERY_MODE_SUM\x10\x01\x12\x15\n\x11QUERY_MODE_REPORT\x10\x02\x32q\n\x0cUsageService\x12\x61\n\x08GetUsage\x12\x1e.stanza.hub.v1.GetUsageRequest\x1a\x1f.stanza.hub.v1.GetUsageResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\"\t/v1/usage:\x01*B\x8a\x01\n\x11\x63om.stanza.hub.v1B\nUsageProtoP\x01Z\x13stanza/hub/v1;hubpb\xa2\x02\x03SHX\xaa\x02\rStanza.Hub.V1\xca\x02\rStanza\\Hub\\V1\xe2\x02\x19Stanza\\Hub\\V1\\GPBMetadata\xea\x02\x0fStanza::Hub::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'stanza.hub.v1.usage_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.stanza.hub.v1B\nUsageProtoP\001Z\023stanza/hub/v1;hubpb\242\002\003SHX\252\002\rStanza.Hub.V1\312\002\rStanza\\Hub\\V1\342\002\031Stanza\\Hub\\V1\\GPBMetadata\352\002\017Stanza::Hub::V1'
  _globals['_GETUSAGEREQUEST'].fields_by_name['environment']._options = None
  _globals['_GETUSAGEREQUEST'].fields_by_name['environment']._serialized_options = b'\342A\001\002'
  _globals['_GETUSAGEREQUEST'].fields_by_name['start_ts']._options = None
  _globals['_GETUSAGEREQUEST'].fields_by_name['start_ts']._serialized_options = b'\342A\001\002'
  _globals['_GETUSAGEREQUEST'].fields_by_name['end_ts']._options = None
  _globals['_GETUSAGEREQUEST'].fields_by_name['end_ts']._serialized_options = b'\342A\001\002'
  _globals['_USAGESERVICE'].methods_by_name['GetUsage']._options = None
  _globals['_USAGESERVICE'].methods_by_name['GetUsage']._serialized_options = b'\202\323\344\223\002\016\"\t/v1/usage:\001*'
  _globals['_QUERYMODE']._serialized_start=2003
  _globals['_QUERYMODE']._serialized_end=2085
  _globals['_GETUSAGEREQUEST']._serialized_start=169
  _globals['_GETUSAGEREQUEST']._serialized_end=1122
  _globals['_GETUSAGERESPONSE']._serialized_start=1124
  _globals['_GETUSAGERESPONSE']._serialized_end=1198
  _globals['_USAGETIMESERIES']._serialized_start=1201
  _globals['_USAGETIMESERIES']._serialized_end=1480
  _globals['_USAGETSDATAPOINT']._serialized_start=1483
  _globals['_USAGETSDATAPOINT']._serialized_end=2001
  _globals['_USAGESERVICE']._serialized_start=2087
  _globals['_USAGESERVICE']._serialized_end=2200
# @@protoc_insertion_point(module_scope)
