# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stanza/hub/v1/auth.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18stanza/hub/v1/auth.proto\x12\rstanza.hub.v1\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"9\n\x15GetBearerTokenRequest\x12 \n\x0b\x65nvironment\x18\x01 \x01(\tR\x0b\x65nvironment\";\n\x16GetBearerTokenResponse\x12!\n\x0c\x62\x65\x61rer_token\x18\x01 \x01(\tR\x0b\x62\x65\x61rerToken2\xaf\x02\n\x0b\x41uthService\x12\x9f\x02\n\x0eGetBearerToken\x12$.stanza.hub.v1.GetBearerTokenRequest\x1a%.stanza.hub.v1.GetBearerTokenResponse\"\xbf\x01\x92\x41\xa5\x01\x12\x10Get Bearer Token\x1aYInspects the X-Stanza-Key auth header and returns a new Bearer Token if API key is valid.J6\n\x03\x32\x30\x30\x12/\n\x02OK\x12)\n\'\x1a%.stanza.hub.v1.GetBearerTokenResponse\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/auth/tokenB\x89\x01\n\x11\x63om.stanza.hub.v1B\tAuthProtoP\x01Z\x13stanza/hub/v1;hubpb\xa2\x02\x03SHX\xaa\x02\rStanza.Hub.V1\xca\x02\rStanza\\Hub\\V1\xe2\x02\x19Stanza\\Hub\\V1\\GPBMetadata\xea\x02\x0fStanza::Hub::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'stanza.hub.v1.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.stanza.hub.v1B\tAuthProtoP\001Z\023stanza/hub/v1;hubpb\242\002\003SHX\252\002\rStanza.Hub.V1\312\002\rStanza\\Hub\\V1\342\002\031Stanza\\Hub\\V1\\GPBMetadata\352\002\017Stanza::Hub::V1'
  _globals['_AUTHSERVICE'].methods_by_name['GetBearerToken']._options = None
  _globals['_AUTHSERVICE'].methods_by_name['GetBearerToken']._serialized_options = b'\222A\245\001\022\020Get Bearer Token\032YInspects the X-Stanza-Key auth header and returns a new Bearer Token if API key is valid.J6\n\003200\022/\n\002OK\022)\n\'\032%.stanza.hub.v1.GetBearerTokenResponse\202\323\344\223\002\020\022\016/v1/auth/token'
  _globals['_GETBEARERTOKENREQUEST']._serialized_start=121
  _globals['_GETBEARERTOKENREQUEST']._serialized_end=178
  _globals['_GETBEARERTOKENRESPONSE']._serialized_start=180
  _globals['_GETBEARERTOKENRESPONSE']._serialized_end=239
  _globals['_AUTHSERVICE']._serialized_start=242
  _globals['_AUTHSERVICE']._serialized_end=545
# @@protoc_insertion_point(module_scope)
